@@ -1,13 +1,25 @@
 # /usr/bin/env python3
-from typing import Set
-from codoc.domain.model import Graph, Node, NodeId, Dependency
-from codoc.domain.helpers import get_node, get_children, set_parent
+from typing import Set, Union
+
+from codoc.domain.helpers import get_children, get_identifiers, get_node
+from codoc.domain.model import Dependency, Graph, Node, NodeId
+from codoc.service.parsing.node import get_identifier_of_object
+
+from .helpers import (
+    is_both_edges_of_edge_in_list_of_nodes,
+    is_either_edges_of_edge_in_list_of_nodes,
+)
 from .types import FilterType
 
 
-def get_children_of(identifier: str, keep_external_nodes: bool = False) -> FilterType:
+# TODO addd a lot more tests to this.
+def get_children_of(
+    node: Union[str, object, Node],
+    keep_external_nodes: bool = False,
+    keep_parents: bool = False,
+) -> FilterType:
     """
-    :param identifier: The string identifier of the parent class we want children of
+    :param node: The node, object or string identifier of what to filter based on
     :param keep_external_nodes: Whether to keep external dependencies of children
     :returns: A filter function that excludes non-children
     :rtype: GraphFilter
@@ -16,28 +28,35 @@ def get_children_of(identifier: str, keep_external_nodes: bool = False) -> Filte
 
     The returned filter (function) can then be called with a given graph.
 
+    **Important**: Children are **NOT** dependencies, they are things defined inside
+    the current node. I.e if a class, Foo, defined in FooModule, then FooModule
+    is the parent of Foo.
+
     Example
 
     .. code-block:: python
 
-        from codoc.service.parsing.node import get_identifier_of_object
+       # returns all modules/classes/exceptions/functions
+       # defined inside `myporject.subproject`.
 
-       identifier = get_identifier_of_object(myproject.subproject)
-       filter_function = get_children_of(identifier)
+       filter_function = filters.get_children_of(myproject.subproject)
 
        filtered_graph = filter_function(graph)
 
-
-
     """
-    if not isinstance(identifier, str):
-        raise TypeError(f"Identifier has to be a str, was a {type(identifier)}")
+    if not isinstance(node, str):
+        if isinstance(node, Node):
+            identifier = node.identifier
+        else:
+            identifier = get_identifier_of_object(node)
+    else:
+        identifier = node
 
     def filter_func(graph: Graph) -> Graph:
         internal_nodes = {
             node for node in graph.nodes if is_node_accepted(node, graph, identifier)
         }
-        internal_node_identifiers = {node.identifier for node in internal_nodes}
+        internal_node_identifiers = get_identifiers(internal_nodes)
         edges = {
             edge
             for edge in graph.edges
@@ -45,63 +64,57 @@ def get_children_of(identifier: str, keep_external_nodes: bool = False) -> Filte
         }
         if not keep_external_nodes:
             return Graph(
-                nodes={
-                    remove_parent_if_parent_is_discarded(
-                        node, internal_node_identifiers
-                    )
-                    for node in internal_nodes
-                },
-                edges=edges,
+                nodes=internal_nodes,
+                edges=graph.edges,
             )
         else:
-            # Also remove `parent_id` for all nodes if parent_id is outside.
-            # TODO keep parent if child is in graph
             return Graph(
                 nodes={
-                    remove_parent_if_parent_is_discarded(node, internal_nodes)
+                    node
                     for node in graph.nodes
                     if is_node_in_edges(node, edges, graph)
                     or is_node_accepted(node, graph, identifier)
                 },
-                edges=edges,
+                edges=graph.edges,
             )
 
     return filter_func
 
 
-def remove_parent_if_parent_is_discarded(
-    node: Node, node_identifiers: Set[str]
-) -> Node:
-    parent_id = node.parent_identifier
-    if parent_id is not None and parent_id not in node_identifiers:
-        return set_parent(node, None)
-    return node
-
-
 # TODO find a way to cache result, i.e dynamic programming
 # TODO test these functions individually
 def is_node_accepted(node: Node, graph: Graph, allowed_identifier: NodeId) -> bool:
-    if node.identifier == allowed_identifier:
-        return True
+    return (
+        node.identifier == allowed_identifier
+        or is_parent_accepted(node, graph, allowed_identifier)
+        or are_children_accepted(node, graph, allowed_identifier)
+    )
 
+
+def is_parent_accepted(node: Node, graph: Graph, allowed_identifier: NodeId) -> bool:
     parent_id = node.parent_identifier
     if not parent_id:
         return False
+    if parent_id == allowed_identifier:
+        return True
 
     parent = get_node(node.parent_identifier, graph)
 
-    return is_node_accepted(parent, graph, allowed_identifier)
+    return is_parent_accepted(parent, graph, allowed_identifier)
+
+
+# TODO
+def are_children_accepted(node: Node, graph: Graph, allowed_identifier: NodeId) -> bool:
+    return False
 
 
 def is_edge_accepted(
     edge: Dependency, node_identifiers: Set[str], keep_external_nodes: bool
 ) -> bool:
-    is_from_node_internal = edge.from_node in node_identifiers
-    is_to_node_internal = edge.to_node in node_identifiers
     if keep_external_nodes:
-        return is_from_node_internal or is_to_node_internal
+        return is_either_edges_of_edge_in_list_of_nodes(edge, node_identifiers)
     else:
-        return is_from_node_internal and is_to_node_internal
+        return is_both_edges_of_edge_in_list_of_nodes(edge, node_identifiers)
 
 
 def is_node_in_edges(node: Node, edges: Set[Dependency], graph: Graph) -> bool:
